@@ -432,14 +432,9 @@ MainWindow::restoreDefaultVideoSettings()
 void
 MainWindow::toggleLoadView()
 {
-    if( engine()->state() == Phonon::PlayingState && TheStream::hasVideo() ) {
-        engine()->playPause();
-    }
-
     if( m_mainView->currentWidget() == m_loadView ) {
         if( m_mainView->indexOf(m_currentWidget) == -1 ) {
             m_mainView->addWidget(m_currentWidget);
-            engine()->playPause();
         }
         m_mainView->setCurrentWidget(m_currentWidget);
         engine()->isPreview(false);
@@ -586,7 +581,8 @@ MainWindow::load( const QUrl &url )
             m_currentWidget = engine();
         } else {
             m_currentWidget = m_audioView;
-            resize(m_currentWidget->minimumSize());
+            if( !isMaximized() )
+                resize(m_currentWidget->minimumSize());
         }
         m_mainView->setCurrentWidget(m_currentWidget);
     }
@@ -610,7 +606,8 @@ MainWindow::play()
             m_currentWidget = engine();
         } else {
             m_currentWidget = m_audioView;
-            resize(m_currentWidget->minimumSize());
+            if( !isMaximized() )
+                resize(m_currentWidget->minimumSize());
         }
         engine()->play();
         m_mainView->setCurrentWidget(m_currentWidget);
